// Class: Example1
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.TextCell;

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.TextCellDisplay;

import edu.kzoo.grid.gui.GridAppFrame;

/**
 *  Grid Package Examples:<br>
 * 
 *    The Example1 class constructs a simple graphical user interface
 *    that displays a bounded grid with several text cells and color
 *    blocks in it.  The format of the text cells and color blocks is
 *    meant to suggest a simple histogram. 
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Example1
{
    // Specify attributes of the grid.
    private static final int NUM_ROWS = 14;
    private static final int NUM_COLS = 18;

    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 800;
    private static final int MAX_HEIGHT = 600;
    private static final int MIN_CELL_SIZE = 10;
    private static final Color BACKGROUND_COLOR = Color.BLUE;

    /**
     *  Start the Example1 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct a window in which to display a grid.  Specify how to
        // display color blocks and text cells.
        GridAppFrame gui = new GridAppFrame();
        gui.constructWindowContents("Example 1: Simple Display",
                                    BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());
        DisplayMap.associate("edu.kzoo.grid.TextCell", new TextCellDisplay());

        // Construct a grid in which to draw.
        Grid grid = new BoundedGrid(NUM_ROWS, NUM_COLS);
        gui.setGrid(grid);

        // Add some color blocks and text cells to the grid in
        // the form of a simple histogram.
        grid.add(new TextCell("1"), new Location(4, 1));
        for ( int i = 0; i < (2 * (NUM_COLS-3)) / 3; i++ )
            grid.add(new ColorBlock(Color.RED), new Location(4, 3 + i));
        grid.add(new TextCell("2"), new Location(9, 1));
        for ( int i = 0; i < (1 * (NUM_COLS-3)) / 3; i++ )
            grid.add(new ColorBlock(Color.YELLOW), new Location(9, 3 + i));

        // Display the grid.
        gui.showGrid();
    }

}
