// Class: Example4AppControl
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import edu.kzoo.grid.Grid;
import edu.kzoo.grid.GridObject;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.gui.GridAppFrame;

/**
 *  Grid Package Examples:<br>
 *
 *    The Example4AppControl class runs an animation of a queen
 *    moving diagonally on a single-colored "chessboard." 
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Example4AppControl
{
    // Instance variable(s) for each Example4AppControl instance.
    private GridAppFrame gui;

    /** Constructs a new Example4AppControl object. **/
    public Example4AppControl(GridAppFrame gui)
    {
        this.gui = gui;
    }

    /** Runs the diagonal queen animation 10 times. **/
    public void runAnimation()
    {
        // Get the grid and determine where the end of the diagonal is
        // (will be lower-right corner unless the grid is not square).
        Grid grid = gui.getGrid();
        int minRowsCols;
        if( grid.numRows() < grid.numCols() )
            minRowsCols = grid.numRows();
        else
            minRowsCols = grid.numCols();

        // Move a queen diagonally from upper-left to lower-right ten times.
        for ( int count = 0; count < 10; count++ )
        {
            // Place the queen in the upper-left corner and display.
            grid.add(new GridObject(), new Location(0, 0));
            gui.showGrid();

            // Move the queen down the diagonal, displaying after each move.
            for ( int newIndex = 1; newIndex < minRowsCols; newIndex++ )
            {
                int oldIndex = newIndex - 1;
                Location oldLoc = new Location(oldIndex, oldIndex);
                Location newLoc = new Location(newIndex, newIndex);
                grid.remove(grid.objectAt(oldLoc));
                grid.add(new GridObject(), newLoc);
                gui.showGrid();
            }
 
            // Remove queen in preparation for next time through outer loop
            grid.remove(grid.objectAt(new Location(minRowsCols - 1,
                                                   minRowsCols - 1)));
        }
    }

}
