// Class: Example6App
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.display.CheckeredBackgroundDisplay;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;
import edu.kzoo.grid.display.ScrollableGridDisplay;

import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.SteppedGridAppController;
import edu.kzoo.grid.gui.SteppedGridAppFrame;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;
import edu.kzoo.util.NamedColor;

/**
 *  Grid Package Examples:<br>
 * 
 *    The Example6App class constructs a graphical user interface that
 *    provides buttons to control an animation of a queen moving
 *    diagonally on a single-colored "chessboard." 
 *
 *  @author Alyce Brady
 *  @version 1 September 2004
 **/
public class Example6App
{
    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.WHITE;

    // Specify button attributes.
    private static final boolean DISPLAY_AFTER = true;
    private static final boolean DISPLAY_AFTER_EACH_STEP = true;

    /**
     *  Start the Example6App program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct the object that will control the animation.
        SteppedGridAppController controller = new Example6SteppedController();

        // Construct a window in which to display a grid.  Include File and
        // Help menus.
        SteppedGridAppFrame gui =
                new SteppedGridAppFrame(controller, DISPLAY_AFTER_EACH_STEP);
        gui.includeMenu(new MinimalFileMenu());
        gui.includeMenu(new ExampleHelpMenu(
            "Example 6: Stepped Animation within the Grid Package",
            "1 September 2004"));


        // Include New Grid, Step, NSteps, Run, Stop, and Restart buttons.
        gui.includeControlComponent(new NewBoundedGridButton(gui, "New Grid"),
                                    EnabledDisabledStates.NEEDS_APP_WAITING);
        gui.includeStepOnceButton();
        gui.includeStepNTimesButton();
        gui.includeRunButton();
        gui.includeStopButton(DISPLAY_AFTER);
        gui.includeSetResetButton("Restart",
                            EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING,
                            DISPLAY_AFTER);

        // Include speed slider, construct window contents, and specify how
        // to display a queen represented as a simple GridObject instance.
        gui.includeSpeedSlider();
        gui.constructWindowContents("Example 6: Stepped Animation",
                                    BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        DisplayMap.associate("edu.kzoo.grid.GridObject",
                             new ScaledImageDisplay("GoldCrown.gif"));

        // Customize the background display to draw a checkered pattern.
        // WARNING: this MUST be done AFTER the call to constructWindowContents
        // because that is when the scrollable display is created.
        ScrollableGridDisplay display = gui.getDisplay();
        display.setBackgroundDisplay(
                new CheckeredBackgroundDisplay(display, NamedColor.WHITE,
                                               NamedColor.BLACK));
    }

}
