// Class: Example7
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.GridObject;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 * 
 *    The Example7 class provides a simple graphical user interface
 *    that is driven by mouse clicks on grid cells.  Each mouse click
 *    places a queen on the current board location or, if there is a
 *    queen there already, removes it. 
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Example7 extends GridAppFrame
{
    // Specify attributes of the grid display.
    private static final int MAX_WIDTH = 400;
    private static final int MAX_HEIGHT = 400;
    private static final int MIN_CELL_SIZE = 20;
    private static final Color BACKGROUND_COLOR = Color.WHITE;

    // Specify attributes of the Start button.
    private static final boolean START_BUTTON_INITIALLY_ENABLED = true;
    private static final boolean DISPLAY_AFTER_START = true;

    /**
     *  Start the Example 7 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Construct the graphical user interface.
        GridAppFrame gui = new Example7();
    }

    /** Constructs a new Example7 object.
     **/
    public Example7()
    {
        // This graphical user interface should include a minimal file
        // menu (consists solely of a Quit option), a Help menu, and
        // a New Grid button.  A queen, represented as a simple
        // GridObject instance, should be displayed as an image of
        // a crown.
        includeMenu(new MinimalFileMenu());
        includeMenu(new ExampleHelpMenu(
            "Example 7: User Interaction through Mouse Clicks " +
            "within the Grid Package",
            "15 August 2004"));
        includeControlComponent(new NewBoundedGridButton(this, "New Grid"),
                                EnabledDisabledStates.NEEDS_APP_WAITING);
        constructWindowContents("Example 7: Clickable Cells",
                                        BACKGROUND_COLOR, 
                                        MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);
        DisplayMap.associate("edu.kzoo.grid.GridObject",
                             new ScaledImageDisplay("GoldCrown.gif"));
    }

    /** Handles a mouse press over the grid display.  Creates a queen
     *  (represented by a generic grid object) in the specified location
     *  if there isn't one there already, or removes the current queen
     *  if there is one.
     **/
    protected void onMousePressOverDisplay(Location loc)
    {
        if ( getGrid().isEmpty(loc) )
            getGrid().add(new GridObject(), loc);
        else
            getGrid().remove(loc);
        showGrid();
    }

}
