// Class: Figure2c
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;

import edu.kzoo.grid.gui.ControlButton;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.ClearGridButton;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 * 
 *    The <code>Figure2c</code> class produces the third in a series of
 *    figures showing different types of grid-based applications in the
 *    Grid Package Overview document.  It shows a snapshot of the
 *    simplified GridPlotter application in Example3.
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class Figure2c
{
    /**
     *  Start the Figure2c program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Figure 2c";
        Color BACKGROUND_COLOR = Color.WHITE;
        int MAX_WIDTH = 400;       // in pixels
        int MAX_HEIGHT = 400;      // in pixels
        int MIN_CELL_SIZE = 20;   // in pixels

        // Construct a window to display a grid.
        GridAppFrame gui = new GridAppFrame();
        gui.includeSpeedSlider();

        // Include a New Grid button.
        gui.includeControlComponent(new NewBoundedGridButton(gui, "New Grid"),
                                    EnabledDisabledStates.NEEDS_APP_WAITING);

        // Include a button that fills the grid with color blocks.
        gui.includeControlComponent(
            new ControlButton(gui, "Fill Grid", true)
                {   public void act()  { /* do nothing */ }    },
            EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING);

        // Include a button that empties the grid.
        gui.includeControlComponent(
                        new ClearGridButton(gui, "Empty Grid", true),
                        EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING);

        gui.constructWindowContents(TITLE, BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);

        // Specify how to display color blocks.
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());

        // Construct a grid in which to draw.
        Grid grid = new BoundedGrid(8, 8);
        gui.setGrid(grid);

        // Illustrate a partially-filled grid -- completely fill 5 rows ...
        for ( int row = 0; row < 5; row++ )
            for ( int col = 0; col < 8; col++ )
                grid.add(new ColorBlock(Color.RED), new Location(row, col));
        // ... and partly fill the 6th row.
        for ( int col = 0; col < 5; col++ )
            grid.add(new ColorBlock(Color.RED), new Location(5, col));

        // Display the grid.
        gui.showGrid();
    }

}
