// Class: OverviewExample2
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.BoundedGrid;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;

import edu.kzoo.grid.display.ColorBlockDisplay;
import edu.kzoo.grid.display.DisplayMap;

import edu.kzoo.grid.gui.GridAppFrame;
import edu.kzoo.grid.gui.nuggets.MinimalFileMenu;

/**
 *  Grid Package Examples:<br>
 * 
 *    The OverviewExample2 class implements the second example in the
 *    Grid Package Overview document.  It constructs a simple graphical
 *    user interface for an animation that fills a grid with color blocks.
 *
 *  @author Alyce Brady
 *  @version 30 June 2004
 **/
public class OverviewExample2
{
    /**
     *  Start the OverviewExample2 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Overview Example 2";
        Color BACKGROUND_COLOR = Color.BLUE;
        int MAX_WIDTH = 600;      // in pixels
        int MAX_HEIGHT = 600;     // in pixels
        int MIN_CELL_SIZE = 10;   // in pixels

        // Construct a window to display an animation in a grid.
        GridAppFrame gui = new GridAppFrame();
        gui.includeMenu(new MinimalFileMenu());
        gui.includeSpeedSlider();  // optional parameters customize slider range
        gui.constructWindowContents(TITLE, BACKGROUND_COLOR, 
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);

        // Specify how to display color blocks.
        DisplayMap.associate("edu.kzoo.grid.ColorBlock",
                             new ColorBlockDisplay());

        // Construct a grid in which to draw.
        Grid grid = new BoundedGrid(10, 10);
        gui.setGrid(grid);

        // Display the initial, empty grid.
        gui.showGrid();

        // Fill the grid with red color blocks in row-major order.
        for ( int row = 0; row < grid.numRows(); row++ )
        {
            for ( int col = 0; col < grid.numCols(); col++ )
            {
                grid.add(new ColorBlock(Color.RED), new Location(row, col));
                gui.showGrid();
            }
        }
    }

}
