// Class: OverviewExample6
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.Grid;
import edu.kzoo.grid.GridObject;
import edu.kzoo.grid.Location;
import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;
import edu.kzoo.grid.gui.EnabledDisabledStates;
import edu.kzoo.grid.gui.SteppedGridAppController;
import edu.kzoo.grid.gui.SteppedGridAppFrame;
import edu.kzoo.grid.gui.nuggets.NewBoundedGridButton;

/**
 *  Grid Package Examples:<br>
 * 
 *    The OverviewExample6 class implements the version of Example 6 provided
 *    in the Grid Package Overview document.  It constructs a simple graphical
 *    user interface for an animation with Step and Run buttons.
 *
 *  @author Alyce Brady
 *  @version 1 September 2004
 **/
public class OverviewExample6
{
    /**
     *  Start the OverviewExample6 program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        String TITLE = "Overview Example 6";
        Color BACKGROUND_COLOR = Color.WHITE;
        int MAX_WIDTH = 600;      // in pixels
        int MAX_HEIGHT = 600;     // in pixels
        int MIN_CELL_SIZE = 10;   // in pixels

        int NEEDS_GRID = EnabledDisabledStates.NEEDS_GRID_AND_APP_WAITING;
        boolean DISPLAY_AFTER_EACH_STEP = true;
        boolean DISPLAY_AFTER_RESTART = true;
        boolean DISPLAY_AFTER_STOP = true;

        QueenAnimation controller = new QueenAnimation();

        SteppedGridAppFrame gui =
                 new SteppedGridAppFrame(controller, DISPLAY_AFTER_EACH_STEP);
        gui.includeControlComponent(new NewBoundedGridButton(gui, "New Grid"),
                                    EnabledDisabledStates.NEEDS_APP_WAITING);
        gui.includeStepOnceButton();
        gui.includeRunButton();
        gui.includeStopButton(DISPLAY_AFTER_STOP);
        gui.includeSetResetButton("Restart", NEEDS_GRID,
                                  DISPLAY_AFTER_RESTART);
        gui.includeSpeedSlider();
        gui.constructWindowContents(TITLE, BACKGROUND_COLOR,
                                    MAX_WIDTH, MAX_HEIGHT, MIN_CELL_SIZE);

        DisplayMap.associate("edu.kzoo.grid.GridObject",
                             new ScaledImageDisplay("GoldCrown.gif"));

     }

    public static class QueenAnimation extends SteppedGridAppController
    {
        private Location currentQueenLoc = new Location(0, 0);

        public void setGrid(Grid grid)
        {
            super.setGrid(grid);
            init();
        }

        public void init()
        {   // If a queen is already on the board, remove her.
            // Insert new queen at location (0, 0).
            getGrid().remove(currentQueenLoc);
            currentQueenLoc = new Location(0, 0);
            new GridObject(getGrid(), currentQueenLoc);
        }

        public void step()
        {   // Remove queen from current location; insert new queen
            // to the lower-right or back at location (0, 0).
            getGrid().remove(currentQueenLoc);
            int newRowCol = (currentQueenLoc.row() + 1) % getGrid().numRows();
            currentQueenLoc = new Location(newRowCol, newRowCol);
            new GridObject(getGrid(), currentQueenLoc);
        }
    }

}
