// Class: RotatedColorObject
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

import edu.kzoo.grid.ColorBlock;
import edu.kzoo.grid.Direction;
import edu.kzoo.grid.Grid;
import edu.kzoo.grid.Location;

/**
 *  Grid Package Examples:<br>
 *
 *  A <code>RotatedColorObject</code> object represents a colored object
 *  in a grid that is facing a direction and keeps track of its direction
 *  as well as its location and color.
 *
 *  @author Alyce Brady
 *  @version 13 December 2003
 *  @see Grid
 *  @see Location
 *  @see Direction
 **/
public class RotatedColorObject extends ColorBlock
{
    // Encapsulated data for each object
    private Direction myDir;           // object's direction

    /** Constructs a colored object facing the specified direction.
     *  @param grid        the grid containing this object
     *  @param loc         the location of the object in <code>grid</code>
     *  @param dir         the direction the object is facing
     *  @param color       the color for this object
     **/
    public RotatedColorObject(Grid grid, Location loc, Direction dir,
                                   Color color)
    {
        super(color, grid, loc);
        myDir = dir;
    }

    /** Returns this colored object's direction.
     *  @return    the direction in which this colored object is facing
     **/
    public Direction direction()
    {
        return myDir;
    }

}
