// Class MBS
//
// Author: Alyce Brady, Joel Booth
//
// This class is based on the College Board's MBSGUI class, as
// allowed by the GNU General Public License.  The MBSGUI class
// is a component class within the AP(r) CS Marine Biology Simulation
// case study (see
// http://www.collegeboard.com/student/testing/ap/compsci_a/case.html).
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

package edu.kzoo.mbsInAGrid;

import edu.kzoo.grid.Direction;

import edu.kzoo.grid.display.DisplayMap;
import edu.kzoo.grid.display.ScaledImageDisplay;
import edu.kzoo.grid.display.RotatedDecorator;
import edu.kzoo.grid.display.ScaledImageTintDecorator;

import edu.kzoo.grid.gui.GridPkgFactory;

import edu.kzoo.mbsInAGrid.display.FishDisplay;
import edu.kzoo.mbsInAGrid.display.LittleFishDisplay;
import edu.kzoo.mbsInAGrid.gui.MBSWindow;

/**
 *  Grid Container Package Examples:<br>
 *
 *  The <code>MBS</code> class provides a main method for a version
 *  of the AP Computer Science Marine Biology Simulation that uses the
 *  Grid Container class library.
 *
 *  @author Alyce Brady (based on code by Brady, Nevison, and Zelenski)
 *  @author Joel Booth (changes made to use decorators)
 *  @version 23 August 2004
 *  @see DisplayMap
 *  @see MBSGUIFrame
 **/
public class MBS
{
    /** Start the Marine Biology Simulation program.
     *  The String arguments (args) are not used in this application.
     **/
    public static void main(String[] args)
    {
        // Tell the GridPkgFactory what grid representations are available
        // for representing bounded and unbounded environments.  If there is
        // more than one representation for a particular type, the graphical
        // user interface will offer the user a choice of representation when
        // an environment is read or created.
        String[] boundedClassNames = {"edu.kzoo.grid.BoundedGrid",
                                      "edu.kzoo.grid.ArrayListGrid$Bounded"};
        String[] unboundedClassNames =
                                    {"edu.kzoo.grid.ArrayListGrid$Unbounded"};
        GridPkgFactory.addBoundedGridClassNames(boundedClassNames);
        GridPkgFactory.addUnboundedGridClassNames(unboundedClassNames);

        // Tell the GridPkgFactory what types of objects can be put in an
        // environment grid.  This list is used to provide a pull-down menu
        // of classes to choose from when manually creating new environments.
        // (It does not affect what types of fish can be created when the
        // environment is being read from a file.)
        String[] fishClassNames = {"edu.kzoo.mbsInAGrid.GridFish",
                                   "edu.kzoo.mbsInAGrid.DarterFish",
                                   "edu.kzoo.mbsInAGrid.SlowFish"};
        GridPkgFactory.addGridObjClassNames(fishClassNames);

        // Specify classes that know how to draw various objects that can
        // be put in an environment grid; in other words, map grid object
        // classes (like GridFish) to display objects (like the FishDisplay
        // object).
        DisplayMap.associate("edu.kzoo.mbsInAGrid.GridFish", new FishDisplay());
        DisplayMap.associate("edu.kzoo.mbsInAGrid.DarterFish", new LittleFishDisplay());

 		// Create a ScaledImageDisplay that uses a RotatedDecorator as 
 		// well as a ScaledImageTintDecorator to associate with a SlowFish.
		ScaledImageDisplay imageDisplay = new ScaledImageDisplay("smallfish.gif");
		imageDisplay.addDecorator(new RotatedDecorator(Direction.EAST));
		imageDisplay.addDecorator(new ScaledImageTintDecorator());      
        DisplayMap.associate("edu.kzoo.mbsInAGrid.SlowFish", imageDisplay);

        // Alternatives include NarrowFishDisplay and RoundFishDisplay.

        // Create and show the window containing the graphical user interface
        MBSWindow mainWindow = new MBSWindow();
    }
}

