// Class: Simulation
//
// Author: Alyce Brady
//
// This class is based on the College Board's Simulation class, as
// allowed by the GNU General Public License.  The original Simulation
// is a component class within the AP(r) CS Marine Biology Simulation
// case study (see
// http://www.collegeboard.com/student/testing/ap/compsci_a/case.html).
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

package edu.kzoo.mbsInAGrid;

import edu.kzoo.grid.Grid;
import edu.kzoo.grid.GridObject;

import edu.kzoo.grid.display.GridDisplay;

import edu.kzoo.util.Debug;

/**
 *  Grid Container Package Examples:<br>
 * 
 *  A <code>Simulation</code> object controls a simulation of fish
 *  movement in an environment represented by a <code>Grid</code>.
 *  Its implementation is similar to that of the <code>Simulation</code>
 *  class in the College Board's Marine Biology Simulation, but
 *  it uses a <code>Grid</code> representation for an environment and the
 *  <code>GridFish</code> variant of the MBS <code>Fish</code> class.
 *
 *  <p>
 *  This <code>Simulation</code> class is based on the College Board's
 *  <code>Simulation</code> class, as allowed by the GNU General
 *  Public License.
 *
 *  @author Alyce Brady
 *  @version 15 February 2004
 *  @see Grid
 *  @see GridDisplay
 *  @see GridFish
 *  @see GridObject
 **/

public class Simulation
{
    // Instance Variables: Encapsulated data for each simulation object
    private Grid theEnv;
    private GridDisplay  theDisplay;

    /** Constructs a <code>Simulation</code> object for a particular
     *  environment.
     *  (Precondition: <code>env</code> and <code>display</code> are
     *  non-null.)
     *  @param env     the environment on which the simulation will run
     *  @param display an object that knows how to display the environment
     **/
    public Simulation(Grid env, GridDisplay display)
    {
        theEnv = env;
        theDisplay = display;

        // Display the initial state of the simulation.
        theDisplay.showGrid();
        Debug.println("-------- Initial Configuration --------");
        Debug.println(theEnv.toString());
        Debug.println("---------------------------------------");
    }

    /** Runs through a single step of this simulation. **/
    public void step()
    {
        // Get all the fish in the environment and ask each
        // one to perform the actions it does in a timestep.
        GridObject[] theFishes = theEnv.allObjects();
        for ( int index = 0; index < theFishes.length; index++ )
        {
            theFishes[index].act();
        }

        // Display the state of the simulation after this timestep.
        theDisplay.showGrid();
        Debug.println(theEnv.toString());
        Debug.println("-------- End of Timestep --------");
    }

}
