// Class: MBSSeedMenu
//
// Author: Alyce Brady
//
// Created on Mar 11, 2004
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

package edu.kzoo.mbsInAGrid.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.ButtonGroup;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JRadioButtonMenuItem;

/**
 *  Grid GUI Support Package:<br>
 *
 *  The <code>MBSSeedMenu</code> class provides a menu bar
 *  for a Grid-based version of the Marine Biology Simulation
 *  with a file menu and a seed menu.
 *
 *  @author Alyce Brady (based on code by Julie Zelenski)
 *  @version Mar 11, 2004
 **/
public class MBSSeedMenu extends JMenu
{
    MBSMenuActionHandler controller;

    /** Creates a seed menu.
     **/
    public MBSSeedMenu(MBSMenuActionHandler handler)
    {
        super("Seed");
        this.controller = handler;
        JMenuItem mItem;

        ButtonGroup bGroup = new ButtonGroup();
        add(mItem = new JRadioButtonMenuItem("Don't reset seed", true));
        bGroup.add(mItem);
        mItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e)
            {
                controller.setSeedOption(MBSMenuActionHandler.DONT_RESET_SEED);
            }});

        add(mItem = new JRadioButtonMenuItem("Use fixed seed..."));
        bGroup.add(mItem);
        mItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e)
            {
                int result =
                    controller.setSeedOption(MBSMenuActionHandler.FIXED_SEED);
                getItem(result).setSelected(true);
            }});

        add(mItem = new JRadioButtonMenuItem("Prompt for seed"));
        bGroup.add(mItem);
        mItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e)
            {
                controller.setSeedOption(MBSMenuActionHandler.PROMPT_SEED);
            }});
    }

}
